@@ -31,7 +31,7 @@ class BaseExecutor:
         This method is responsible for executing a node.
         But given that a node itself could be a dag in cases of parallel, map and dag, this method handles the cases.
         If the node is of type task, success, fail: we can pretty much execute it and we call self.trigger_job.
-        If the node is of type dag, map, parallel: We call the node's execute_as_graph function which internally
+        If the node is of type composite: We call the node's execute_as_graph function which internally
         triggers execute_graph in-turn iteratively traverses the graph.
 
 
@@ -70,7 +70,7 @@ class BaseExecutor:
         self.secrets_handler = None
         self.variables_file = None
         self.configuration_file = None
-        self.cmd_line_arguments = {}
+        self.parameters_file = None
 
     def is_parallel_execution(self) -> bool:  # pylint: disable=R0201
         """
@@ -92,7 +92,10 @@ class BaseExecutor:
         run_log.status = defaults.PROCESSING
         run_log.dag_hash = self.dag_hash
 
-        parameters = self.cmd_line_arguments
+        parameters = {}
+        if self.parameters_file:
+            parameters = utils.load_yaml(self.parameters_file)
+
         if self.previous_run_log:
             run_log.original_run_id = self.previous_run_log.run_id
             # Sync the previous run log catalog to this one.
@@ -308,7 +311,7 @@ class BaseExecutor:
             return
 
         # We call an internal function to iterate the sub graphs and execute them
-        if node.node_type in ['parallel', 'dag', 'map']:
+        if node.is_composite:
             self.run_log_store.add_step_log(step_log, self.run_id)
             node.execute_as_graph(self, map_variable=map_variable, **kwargs)
             return
@@ -521,7 +524,8 @@ class LocalContainerExecutor(BaseExecutor):
       steps:
         step:
           mode_config:
-            docker_image: The image that you want that single step to run in.
+            local-container:
+                docker_image: The image that you want that single step to run in.
     This image would only be used for that step only.
 
     This mode does not build the docker image with the latest code for you, it is still left for the user to build
@@ -570,7 +574,7 @@ class LocalContainerExecutor(BaseExecutor):
         """
 
         super().add_code_identities(node, step_log)
-        mode_config = {**self.config, **node.get_mode_config()}
+        mode_config = {**self.config, **node.get_mode_config(self.service_name)}
 
         docker_image = mode_config.get('docker_image', None)
         if docker_image:
@@ -622,7 +626,8 @@ class LocalContainerExecutor(BaseExecutor):
         try:
             action = utils.get_node_execution_command(self, node, map_variable=map_variable)
             logger.info(f'Running the command {action}')
-            mode_config = {**self.config, **node.get_mode_config()}  #  Overrides global config with local
+            #  Overrides global config with local
+            mode_config = {**self.config, **node.get_mode_config(self.service_name)}
             docker_image = mode_config.get('docker_image', None)
             if not docker_image:
                 raise Exception(
@@ -823,7 +828,7 @@ class DemoRenderer(BaseExecutor):
         while True:
             working_on = dag.get_node_by_name(current_node)
 
-            if working_on.node_type in ['parallel', 'dag', 'map']:
+            if working_on.is_composite:
                 raise NotImplementedError('In this demo version, composite nodes are not implemented')
 
             if previous_node == current_node:
@@ -839,7 +844,9 @@ class DemoRenderer(BaseExecutor):
 
             if working_on.node_type not in ['success', 'fail']:
                 if working_on.node_type == 'as-is':
-                    bash_script_lines.append(working_on.render_string + '\n')  # type: ignore
+                    command_config = working_on.config.get('command_config', {})
+                    if 'render_string' in command_config:
+                        bash_script_lines.append(command_config['render_string'] + '\n')
                 else:
                     bash_script_lines.append(f'{execute_node_command}\n')
 
